@@ -56,7 +56,7 @@ id.dc <- function(x, PIT = FALSE){
   # if(is.null(residuals(x))){
   #   stop("No residuals retrieved from model")
   # }
-  u <- Tob <- p <- k <- residY <- coef_x <- yOut <- type <- y <-  NULL
+  u <- Tob <- p <- k <- residY <- coef_x <- yOut <- type <- y <- A_hat <-  NULL
   get_var_objects(x)
   ########### starting the computations ------------------------------------------------------------------------
 
@@ -73,15 +73,15 @@ id.dc <- function(x, PIT = FALSE){
   P <- P_chol%*%ICA$W
 
   # obtaining VAR parameter
-  if(inherits(x, "var.boot")){
-    A_hat <- coef_x
-  }else{
-    if(type == "none"){
-      A_hat <- vars::Bcoef(x)
-    }else{
-    A_hat <- vars::Bcoef(x)[, c((k * p+1):ncol(vars::Bcoef(x)),1:(k * p))]
-    }
-  }
+  # if(inherits(x, "var.boot")){
+  #   A_hat <- coef_x
+  # }else{
+  #   if(type == "none"){
+  #     A_hat <- vars::Bcoef(x)
+  #   }else{
+  #   A_hat <- vars::Bcoef(x)[, c((k * p+1):ncol(vars::Bcoef(x)),1:(k * p))]
+  #   }
+  # }
 
 
   #   if(inherits(x, "var.boot")){
